@@ -25,7 +25,7 @@ use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $AUTOLOAD);
 require Exporter;
 require DynaLoader;
 
-our $VERSION='0.76';
+our $VERSION='0.79';
 
 @ISA = qw(Exporter DynaLoader);
 %EXPORT_TAGS = (nodetypes => [qw(BTAST_STRING BTAST_MACRO BTAST_NUMBER)],
@@ -93,6 +93,8 @@ sub split_list {
 
 }
 
+=encoding UTF-8
+
 =head1 NAME
 
 Text::BibTeX - interface to read and parse BibTeX files
@@ -101,10 +103,10 @@ Text::BibTeX - interface to read and parse BibTeX files
 
    use Text::BibTeX;
 
-   $bibfile = Text::BibTeX::File->new("foo.bib");
-   $newfile = Text::BibTeX::File->new(">newfoo.bib");
+   my $bibfile = Text::BibTeX::File->new("foo.bib");
+   my $newfile = Text::BibTeX::File->new(">newfoo.bib");
 
-   while ($entry = Text::BibTeX::Entry->($bibfile))
+   while ($entry = Text::BibTeX::Entry->new($bibfile))
    {
       next unless $entry->parse_ok;
 
